__author__ = 'Jessica S. Yu'

# Bagheri Lab
# McCormick School of Engineering
# Northwestern University
# 
# Script will print out five search strings (one for each physical length
# scale) to use w/ PubMed search function. 
#
# USAGE
#	>> python CurrentOpinionSearchString.py MODEL_CODE IS_STOCHASTIC
#
# INPUTS
#	MODEL_CODE = integer identification for the model type
#		0 = Boolean Network
# 		1 = Molecular Dynamics
#		2 = Algebraic Equations
#		3 = Markov Model
#		4 = Differential Equation (ordinary or partial)
#		5 = Differential Equation (use w/ IS_STOCHASTIC = 1 for SDE)
#		6 = Cellular Automata
#		7 = Agent-Based Model
#		8 = BioNetGen/Rule-Based
#	IS_STOCHASTIC = boolean for explicitely including stochastic search terms
#		0 = required to not have stochastic terms
#		1 = required to have stochastic terms 
#		(anything else) = stochasticity not specified

from sys import argv

bio = '"Models, Biological"[MH]'
ss = ' NOT (multi-scale OR multiscale OR "multiple scales" OR "multiple length scales" OR "multiple spatial scales" OR "multiple time scales" OR "multiple temporal scales")'
rev = ' NOT ("review"[publication type] OR "review"[title])'

models = [	['Boolean Network','Boolean Networks'], 
			['Molecular Dynamics','Coarse Grain Molecular Dynamics'],
			['Algebraic Equation','Algebraic Equations'],
			['Markov Model','Markov Chain'],
			['Ordinary Differential','Partial Differential'],
			['Differential Equation'],
			['Cellular Automata'],
			['Agent Based','Agent-based'],
			['BioNetGen','Rule-Based']]

scales = [	['atom','atoms','molecule','molecules','amino acid','amino acids','genetic code','codon'],
			['protein','proteins','lipid','lipids','folding','membrane','membranes','DNA formation','transcription factor','transcription factors','polymerase'],
			['pathway','pathways','protein network','protein networks','signal transduction','cell signaling','protein interaction network','circuit','circuits','regulatory network','regulatory networks','transcription factor network','transcription factor networks','reaction diffusion','regulatory network','regulatory networks','signalling','signaling'],
			['cell','single cell','individual cell','cell behavior','cell metabolism','cell migration','cell movement','cell phenotype','cell division','differentiation','apoptosis','cell growth'],
			['cell-cell interactions','tissue','cell population','cell populations','colony','colonies','biofilm']]

auxs = [['cell','cells','signaling','circuit','interaction','body','regulatory','pathway','aggregation','protein','response','implant','development','population','transport'],
		scales[2],
		scales[3] + ['folding','population','cell'],
		['amino acid','substrate prediction','membrane','DNA','population','aggregation'],
		['single cell','individual cell','docking']]

model = models[int(argv[1])]
model = ['"' + x + '"' for x in model]
model = ' AND (' + '[title/abstract] OR '.join(model) + '[title/abstract])'

# Remove or require stochastic for models that have both
if int(argv[2]) == 0:
	rand = ' NOT (' + ' OR '.join(['Stochastic','Random']) + ')'
elif int(argv[2]) == 1:
	rand = ' AND (' + ' OR '.join(['Stochastic','Random']) + ')'
else:
	rand = ''

if int(argv[1]) == 8:
	model = model + ' NOT ("Agent Based" OR "Agent-based" OR "Cellular Automata")'

for s in range(0,5):
	scale = scales[s]
	scale = ['"' + x + '"' for x in scale]
	scale = ' AND (' + '[title/abstract] OR '.join(scale) + '[title/abstract])'

	aux = auxs[s]
	aux = ['"' + x + '"' for x in aux]
	aux = ' NOT (' + ' OR '.join(aux) + ')'

	search = bio + ss + rev + rand + model + scale + aux
	print '\n' + search + '\n'


